@@ -16,4 +16,7 @@ class Database_Handler:
     
     def update_record(self, **keywords):
         return self.handler.update_record(**keywords)
+    
+    def delete_record(self, keywords):
+        return self.handler.delete_record(keywords)
     
\ No newline at end of file
