@@ -222,7 +222,7 @@ class Postgres_Handler:
 
             if id_key not in kwargs: assert("Error: ID of record required for an update!")
             
-            query_string += f' WHERE "ID"=%(Id)s'
+            query_string += f' WHERE "ID"=%(ID)s'
             values_dict[id_key] = kwargs[id_key]
             
             sql_string = sql.SQL(query_string).format(table_name = sql.Identifier(kwargs[self.table_name_key]))
